@@ -136,12 +136,12 @@ class TimeoutSampler:
 
                 time.sleep(self.sleep)
 
-            except self._exceptions as exp:
+            except Exception as exp:
                 last_exp = exp
                 last_exp_log = self._get_exception_log(exp=last_exp)
                 if self._is_raisable_exception(exp=last_exp):
                     LOGGER.error(last_exp_log)
-                    raise exp
+                    raise TimeoutExpiredError(self._get_exception_log(exp=last_exp))
 
                 self.elapsed_time = None
                 time.sleep(self.sleep)
